@@ -1,6 +1,9 @@
-from django.contrib.auth import get_user_model
+from django.contrib.auth import authenticate, get_user_model
 from django.utils.translation import ugettext_lazy as _
 from rest_framework import serializers
+from rest_framework.authtoken.serializers import (
+    AuthTokenSerializer as DRFAuthTokenSerializer
+)
 
 
 User = get_user_model()
@@ -20,6 +23,25 @@ class ValidateEmailMixin(object):
             raise serializers.ValidationError(msg)
 
 
+class AuthTokenSerializer(DRFAuthTokenSerializer):
+    """
+    Fix DRF's error messages (which ain't very helpful).
+
+    Also, end the indentation nonsense.
+    """
+    def validate(self, attrs):
+        username = attrs.get('username')
+        password = attrs.get('password')
+
+        user = authenticate(username=username, password=password)
+        if not user:
+            msg = _('Unable to log in with provided credentials.')
+            raise serializers.ValidationError(msg)
+
+        attrs['user'] = user
+        return attrs
+
+
 class RegistrationSerializer(ValidateEmailMixin, serializers.ModelSerializer):
     password = serializers.CharField(write_only=True, min_length=8, label=_('Password'))
     password2 = serializers.CharField(write_only=True, min_length=8, label=_('Repeat password'))
